Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1329)

Unified Diff: Source/core/inspector/WorkerDebuggerAgent.cpp

Issue 1115923002: workers: Rename WorkerThread to WorkerScript. Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: . Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/inspector/WorkerDebuggerAgent.cpp
diff --git a/Source/core/inspector/WorkerDebuggerAgent.cpp b/Source/core/inspector/WorkerDebuggerAgent.cpp
index d4abe3f7da2b97163f76d67d3600413853bfdbf0..d800c6146d4c07ea9dc1ab9da53a848216461c3c 100644
--- a/Source/core/inspector/WorkerDebuggerAgent.cpp
+++ b/Source/core/inspector/WorkerDebuggerAgent.cpp
@@ -35,7 +35,7 @@
#include "core/inspector/InjectedScript.h"
#include "core/inspector/WorkerInspectorController.h"
#include "core/workers/WorkerGlobalScope.h"
-#include "core/workers/WorkerThread.h"
+#include "core/workers/WorkerScript.h"
#include "wtf/MessageQueue.h"
namespace blink {
@@ -44,20 +44,20 @@ namespace {
class RunInspectorCommandsTask final : public ScriptDebugServer::Task {
public:
- explicit RunInspectorCommandsTask(WorkerThread* thread)
- : m_thread(thread) { }
+ explicit RunInspectorCommandsTask(WorkerScript* script)
+ : m_script(script) { }
virtual ~RunInspectorCommandsTask() { }
virtual void run() override
{
// Process all queued debugger commands. WorkerThread is certainly
// alive if this task is being executed.
- m_thread->willEnterNestedLoop();
- while (MessageQueueMessageReceived == m_thread->runDebuggerTask(WorkerThread::DontWaitForMessage)) { }
- m_thread->didLeaveNestedLoop();
+ m_script->willEnterNestedLoop();
+ while (MessageQueueMessageReceived == m_script->runDebuggerTask(WorkerScript::DontWaitForMessage)) { }
+ m_script->didLeaveNestedLoop();
}
private:
- WorkerThread* m_thread;
+ WorkerScript* m_script;
};
} // namespace
@@ -86,7 +86,7 @@ DEFINE_TRACE(WorkerDebuggerAgent)
void WorkerDebuggerAgent::interruptAndDispatchInspectorCommands()
{
- scriptDebugServer().interruptAndRun(adoptPtr(new RunInspectorCommandsTask(m_inspectedWorkerGlobalScope->thread())));
+ scriptDebugServer().interruptAndRun(adoptPtr(new RunInspectorCommandsTask(m_inspectedWorkerGlobalScope->script())));
}
void WorkerDebuggerAgent::startListeningScriptDebugServer()
@@ -107,7 +107,7 @@ WorkerScriptDebugServer& WorkerDebuggerAgent::scriptDebugServer()
InjectedScript WorkerDebuggerAgent::injectedScriptForEval(ErrorString* error, const int* executionContextId)
{
if (!executionContextId)
- return injectedScriptManager()->injectedScriptFor(m_inspectedWorkerGlobalScope->script()->scriptState());
+ return injectedScriptManager()->injectedScriptFor(m_inspectedWorkerGlobalScope->scriptController()->scriptState());
InjectedScript injectedScript = injectedScriptManager()->injectedScriptForId(*executionContextId);
if (injectedScript.isEmpty())
@@ -44,20 +44,20 @@ namespace {
virtual void run() override
{
- // Process all queued debugger commands. WorkerThread is certainly
+ // Process all queued debugger commands. WorkerScript is certainly
// alive if this task is being executed.

Powered by Google App Engine
This is Rietveld 408576698